Update to hplip-3.25.8.

This commit is contained in:
ajacoutot
2025-11-18 10:04:39 +00:00
parent d149f5f73d
commit 80323df837
5 changed files with 40 additions and 39 deletions
+1 -3
View File
@@ -7,7 +7,7 @@ COMMENT-hpcups= HP native CUPS driver
COMMENT-hpijs= HP ghostscript driver (spooler independent)
COMMENT-gui= HPLIP graphical tools
V= 3.25.6
V= 3.25.8
DISTNAME= hplip-${V}
SUBST_VARS= V
@@ -18,8 +18,6 @@ PKGNAME-hpcups= hpcups-${V}
PKGNAME-hpijs= hpijs-${V}
PKGNAME-gui= hplip-gui-${V}
REVISION-main= 0
SHARED_LIBS += hpdiscovery 0.0 # 0.1
SHARED_LIBS += hpmud 2.0 # 0.6
SHARED_LIBS += hpipp 0.0 # 0.1
+2 -2
View File
@@ -1,2 +1,2 @@
SHA256 (hplip-3.25.6.tar.gz) = pq8xSnrwVy8qtpZ7L+aHYOZNdGKO8OYjf4UE2BBH7b4=
SIZE (hplip-3.25.6.tar.gz) = 30464428
SHA256 (hplip-3.25.8.tar.gz) = HPbWwoc1Q1yOtmRug7z7ch5RxLHw6M+RBab6+W3JrSU=
SIZE (hplip-3.25.8.tar.gz) = 30874051
+9 -9
View File
@@ -39,7 +39,7 @@ Index: Makefile.in
prnt/ipp-usb/HPLIP.conf scan/sane/hpaio.desc \
installer/text_install.py data/localization/hplip_de.ts \
data/localization/hplip_es.ts data/localization/hplip_fr.ts \
@@ -4900,7 +4896,7 @@ dist_unrel_DATA =
@@ -4940,7 +4936,7 @@ dist_unrel_DATA =
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ scan/sane/orblitei.h scan/sane/orblite.h scan/sane/orblite.c \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ scan/sane/OrbliteScan/LinuxCommon.h scan/sane/OrbliteScan/MacCommon.h
@@ -48,7 +48,7 @@ Index: Makefile.in
@DARWIN_BUILD_TRUE@@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@libsane_hpaio_la_LDFLAGS = -module -framework CoreFoundation -version-info 1:0:0
# The following is a interlibrary dependency that must be compiled first.
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@libsane_hpaio_la_LIBADD = libhpip.la \
@@ -4908,7 +4904,6 @@ dist_unrel_DATA =
@@ -4948,7 +4944,6 @@ dist_unrel_DATA =
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ libhpipp.la \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ $(DBUS_LIBS) \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ -lcups \
@@ -56,7 +56,7 @@ Index: Makefile.in
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@ $(am__append_1)
#libsane_hpaio_la_CFLAGS = -DWITH_NONAMESPACES -DSOAP_DEBUG
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@@SCAN_BUILD_TRUE@libsane_hpaio_la_CFLAGS = $(DBUS_CFLAGS) \
@@ -4930,7 +4925,6 @@ dist_unrel_DATA =
@@ -4970,7 +4965,6 @@ dist_unrel_DATA =
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@libhpmud_la_LDFLAGS = \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@ -version-info \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@ 0:6:0 -lpthread \
@@ -64,7 +64,7 @@ Index: Makefile.in
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@ $(am__append_6) \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@ $(am__append_9) \
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@ $(am__append_11)
@@ -4984,7 +4978,7 @@ dist_unrel_DATA =
@@ -5024,7 +5018,7 @@ dist_unrel_DATA =
@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@pstotiff_SCRIPTS = fax/filters/pstotiff
# hplip.state
@@ -73,7 +73,7 @@ Index: Makefile.in
@HPLIP_BUILD_TRUE@dist_hplip_state_DATA =
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@@HPLIP_CLASS_DRIVER_FALSE@dist_hplip_SCRIPTS = hpssd.py __init__.py hpdio.py
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@cmddir = $(hplipdir)
@@ -5182,7 +5176,7 @@ dist_unrel_DATA =
@@ -5222,7 +5216,7 @@ dist_unrel_DATA =
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_SOURCES = prnt/hpijs/PrinterProperties.cpp prnt/hpijs/PrinterProperties.h prnt/hpijs/bug.h
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_CXXFLAGS = $(libapdk_la_CXXFLAGS)
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_CFLAGS = $(libapdk_la_CFLAGS)
@@ -82,7 +82,7 @@ Index: Makefile.in
# hplip.desktop
@FULL_BUILD_TRUE@@GUI_BUILD_TRUE@@HPLIP_BUILD_TRUE@hplip_desktopdir = $(icondir)
@@ -5251,8 +5245,8 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@@ -5291,8 +5285,8 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@HPIJS_INSTALL_TRUE@hpijs_CXXFLAGS = $(libapdk_la_CXXFLAGS)
@HPIJS_INSTALL_TRUE@hpijs_CFLAGS = $(libapdk_la_CFLAGS)
@@ -93,7 +93,7 @@ Index: Makefile.in
# hpcups
#if NEW_HPCUPS
@@ -5296,7 +5290,7 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@@ -5336,7 +5330,7 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@HPCUPS_INSTALL_TRUE@ prnt/hpcups/ImageProcessor.h
@HPCUPS_INSTALL_TRUE@hpcups_CXXFLAGS = $(APDK_ENDIAN_FLAG) $(DBUS_CFLAGS)
@@ -102,7 +102,7 @@ Index: Makefile.in
#else
#hpcupsdir = $(cupsfilterdir)
#hpcups_PROGRAMS = hpcups
@@ -5304,21 +5298,21 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@@ -5344,21 +5338,21 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
#hpcups_CXXFLAGS = $(libapdk_la_CXXFLAGS)
#hpcups_CFLAGS = $(libapdk_la_CFLAGS)
#if HPCUPS_ONLY_BUILD
@@ -128,7 +128,7 @@ Index: Makefile.in
dat2drvdir = $(hplipdir)
dat2drv_SOURCES = Common.h Dat2drv.cpp Dat2drv.h Normalize.cpp Normalize.h
@GCC_GE_47_TRUE@dat2drv_CXXFLAGS = -std=c++11
@@ -10268,19 +10262,9 @@ uninstall-am: uninstall-apparmor_abstractionDATA \
@@ -10308,19 +10302,9 @@ uninstall-am: uninstall-apparmor_abstractionDATA \
install-data-hook:
+8 -25
View File
@@ -1,7 +1,7 @@
Index: prnt/cups.py
--- prnt/cups.py.orig
+++ prnt/cups.py
@@ -236,8 +236,8 @@ def isfamilydrv(ppds):
@@ -238,8 +238,8 @@ def isfamilydrv(ppds):
def getPPDPath(addtional_paths=None):
"""
@@ -12,7 +12,7 @@ Index: prnt/cups.py
"""
if addtional_paths is None:
addtional_paths = []
@@ -267,16 +267,16 @@ def getPPDPath1(addtional_paths=None):
@@ -271,16 +271,16 @@ def getPPDPath1(addtional_paths=None):
def getAllowableMIMETypes():
"""
@@ -34,33 +34,16 @@ Index: prnt/cups.py
for path in paths:
files.extend(glob.glob(path))
for f in files:
@@ -337,11 +337,11 @@ def getSystemPPDs():
else: # 1.2.x
log.debug("(CUPS 1.2.x) Getting list of PPDs using CUPS_GET_PPDS...")
ppd_dict = cupsext.getPPDList()
- cups_ppd_path = getPPDPath() # usually /usr/share/cups/model
- foomatic_ppd_path = sys_conf.get('dirs', 'ppdbase', '/usr/share/ppd')
+ cups_ppd_path = getPPDPath() # usually ${LOCALBASE}/share/cups/model
+ foomatic_ppd_path = sys_conf.get('dirs', 'ppdbase', '${LOCALBASE}/share/ppd')
@@ -341,7 +341,7 @@ def getSystemPPDs():
foomatic_ppd_path = sys_conf.get('dirs', 'ppdbase', '/usr/share/ppd')
if not foomatic_ppd_path or not os.path.exists(foomatic_ppd_path):
- foomatic_ppd_path = '/usr/share/ppd'
+ foomatic_ppd_path = '${LOCALBASE}/share/foomatic/db/source/PPD'
log.debug("CUPS PPD base path = %s" % cups_ppd_path)
log.debug("Foomatic PPD base path = %s" % foomatic_ppd_path)
@@ -360,8 +360,8 @@ def getSystemPPDs():
'gutenprint' in ppd):
# PPD files returned by CUPS_GET_PPDS (and by lpinfo -m)
# can be relative to /usr/share/ppd/ or to
# /usr/share/cups/model/. Not sure why this is.
# Here we will try both and see which one it is...
if os.path.exists(ppd):
@@ -419,7 +419,7 @@ number_pat = re.compile(r""".*?(\d+)""", re.IGNORECASE
@@ -425,7 +425,7 @@ number_pat = re.compile(r""".*?(\d+)""", re.IGNORECASE
STRIP_STRINGS2 = ['foomatic:', 'hp-', 'hp_', 'hp ', '.gz', '.ppd',
'drv:', '-pcl', '-pcl3', '-jetready',
'-zxs', '-zjs', '-ps', '-postscript', '-pdf',
@@ -69,7 +52,7 @@ Index: prnt/cups.py
for p in list(models.TECH_CLASS_PDLS.values()):
@@ -703,7 +703,7 @@ def getFaxPPDFile(mq, model):
@@ -709,7 +709,7 @@ def getFaxPPDFile(mq, model):
def getErrorLogLevel():
+20
View File
@@ -689,6 +689,8 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_5200l-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5200l-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5200lx-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5200lx.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5501-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5502-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5l.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5mp-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5mp-ps.ppd.gz
@@ -699,6 +701,8 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_5si-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5si_mopier-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5si_mopier-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_600_m601_m602_m603-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_6500-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_6501-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_6l.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_6mp-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_6mp-ps.ppd.gz
@@ -746,6 +750,7 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_color_flow_mfp_m575-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_cp1025.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_cp1025nw.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_cp1520_series-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_d50452-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_e40040-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_e50145-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_e60055-e60075-ps.ppd.gz
@@ -760,6 +765,8 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_flow_e73140-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_e82650-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_e82660-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_e82670-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_5602-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_6600-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_e52645-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_e731-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_e826-ps.ppd.gz
@@ -767,6 +774,8 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_m525-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_m528-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_m630-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_m830-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_x530-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_flow_mfp_x627-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m1005.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m101-m106.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m109-m112.ppd.gz
@@ -812,7 +821,11 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_m9050_mfp-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9050_mfp-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9059_mfp-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9059_mfp-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_5601-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_5602-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_6600-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_8601-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_d53052-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_e42540-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_e72425-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_e72430-ps.ppd.gz
@@ -844,6 +857,9 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m630-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m631_m632_m633-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m634_m635_m636-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m725-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_x529-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_x530-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_x627-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1005.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1006.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1007.ppd.gz
@@ -977,6 +993,10 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_tank_250x.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_tank_mfp_1005.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_tank_mfp_160x.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_tank_mfp_260x.ppd.gz
@@ -360,8 +360,8 @@ def getSystemPPDs():
'gutenprint' in ppd):
# PPD files returned by CUPS_GET_PPDS (and by lpinfo -m)
- # can be relative to /usr/share/ppd/ or to
- # /usr/share/cups/model/. Not sure why this is.
+ # can be relative to ${LOCALBASE}/share/ppd/ or to
+ # ${LOCALBASE}/share/cups/model/. Not sure why this is.
# Here we will try both and see which one it is...
if os.path.exists(ppd):
share/foomatic/db/source/PPD/HP/hp-laserjet_x503-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_x504-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_x602-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_x603-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-lj_300_400_color_m351_m451-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-lj_300_400_color_mfp_m375_m475-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-mopier_240-pcl3.ppd.gz